@@ -23,10 +23,11 @@ __PACKAGE__->mk_accessors(
         do_not_hilite
         snipper_config
         hiliter_config
+        parser_config
         )
 );
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 use Rose::Object::MakeMethods::Generic (
     'scalar --get_set_init' => 'searcher', );
@@ -48,6 +49,7 @@ sub init {
     $self->{do_not_hilite}  ||= {};
     $self->{snipper_config} ||= { as_sentences => 1 };
     $self->{hiliter_config} ||= {};
+    $self->{parser_config}  ||= {};
 
     return $self;
 }
@@ -96,6 +98,7 @@ sub search {
         $query,
         {   start          => $offset,
             max            => $page_size,
+            order          => $sort_by,
             limit          => \@limits,
             default_boolop => $boolop,
         }
@@ -175,12 +178,12 @@ sub build_results {
     my $count          = 0;
     my %snipper_config = %{ $self->{snipper_config} };
     my %hiliter_config = %{ $self->{hiliter_config} };
-
-    # TODO how to pass in a stemmer if necessary to the ST->parser?
-    my $XMLer   = Search::Tools::XML->new;
-    my $query   = Search::Tools->parser()->parse($q);
+    my %parser_config  = %{ $self->{parser_config} };
+    my $XMLer          = Search::Tools::XML->new;
+    my $query          = Search::Tools->parser(%parser_config)->parse($q);
     my $snipper = Search::Tools->snipper( query => $query, %snipper_config );
     my $hiliter = Search::Tools->hiliter( query => $query, %hiliter_config );
+
     while ( my $result = $results->next ) {
         push @results,
             $self->process_result(
@@ -407,6 +410,10 @@ Get/set the hash ref of Search::Tools::Snipper->new params.
 
 Get/set the hash ref of Search::Tools::HiLiter->new params.
 
+=head2 parser_config
+
+Get/set the hash ref of Search::Tools::QueryParser->new params.
+
 =head2 no_hiliting( I<field_name> )
 
 By default, looks up I<field_name> in the do_no_hilite() hash, but
